@@ -29,7 +29,7 @@ except:
 class GipPrefs:
     """Giplet Preferences Class"""
     def __init__(self, _conf_path):
-        self.interface = 'eth0 www.getmyip.org'
+        self.interface = 'eth0 wlan0 www.whatismyip.org'
         self.interval = 10
         self.conf_client = gconf.client_get_default()
         self.conf_path = _conf_path
@@ -62,7 +62,11 @@ class GipPrefsDlg:
         #Set the Glade File
         self.gladefile = gipglobals.RES_DIR + "/giplet.glade"
         self.gipPrefs = gipPrefs
-        self.getControls()                    
+        self.getControls()
+        self.txtInterface.set_tooltip_text(
+            _("giplet shows the first availalbe IP.\nRemove eth*/wlan* if you wanna an external IP."))
+        self.txtTimer.set_tooltip_text(
+            _("Tell giplet how long to probe IP again, in minute"))
         self.setValues()
         
     def getControls(self):
